````java
import com.jd.sentry.performance.moblietraffic.RequestInfoCollector;
import com.jingdong.app.util.image.assist.JDFailReason;
import com.jingdong.common.config.IExceptionReportHandler;
import com.jingdong.common.config.IHttpDnsDependency;
import com.jingdong.common.config.IImageController;
import com.jingdong.common.config.INetStatReporter;
import com.jingdong.common.config.INetworkParameter;
import com.jingdong.common.config.IOtherDependency;
import com.jingdong.common.httpdns.IpModel;
import com.jingdong.common.network.JDNetworkDependencyFactory;
import com.jingdong.common.runTimeConfig.ConfigUtil;
import com.jingdong.common.utils.JDImageUtils;
import com.jingdong.common.utils.NoImageUtils;
import com.jingdong.jdsdk.crash.PageInfoUtils;
import com.jingdong.jdsdk.depend.DependUtil;
import com.jingdong.jdsdk.network.toolbox.ExceptionReporter;
import com.jingdong.jdsdk.network.utils.JDDnsUtil;
import com.jingdong.jdsdk.network.utils.StatSharePreferenceUtil;
import com.jingdong.sdk.jdhttpdns.JDHttpDnsToolkit;

import java.util.HashMap;

/**
 *
 * 京东主站，图片依赖设置工厂
 */

public class JDImageConfigFactory {

    /**
     * 新增图片请求首次请求失败异常上报
     * @return
     */
    public static IExceptionReportHandler getExceptionReportHandlerImpl() {
        return new IExceptionReportHandler() {
            /**
             * @param url----图片URL
             * @param jdFailReason----显示出错对象
             * @param pageInfo----pageInfo信息
             */

            @Override
            public void reportBitmapException(String url, JDFailReason jdFailReason, String pageInfo) {
                Throwable cause = jdFailReason.getCause();
                if (cause != null && cause instanceof IllegalArgumentException) {
                    if (url != null && url.equals(JDImageUtils.FAKE_URI_EMPTY)) {
                        return;
                    }
                }
                ExceptionReporter.reportBitmapException(url,jdFailReason, pageInfo);
            }

            /**
             * dpg统计埋点
             * @param imageUrl
             */
            @Override
            public void reportDpgPicMta(String imageUrl) {
                ExceptionReporter.reportDpgPicMta(imageUrl);
            }

            @Override
            public void reportClearTextRequest(String requestUrl) {
                ExceptionReporter.reportFrescoClearTextRequest(requestUrl);
            }
        };
    }

    /**
     * 获取网络参数接口
     * @return
     */
    public static INetworkParameter getNetworkParameterImpl(){
        return new INetworkParameter() {
            /**
             * 图片请求是否使用域名请求发起
             * @return
             */
            @Override
            public boolean isUseDomainFlag() {
                return !JDDnsUtil.getIntance().isImageDnsControlEnable();
            }

            /**
             * OKHTTP开关
             * @return
             */
            @Override
            public boolean isUseOKHttp() {
                return DependUtil.getInstance().getDepend().isUseOkhttp();
            }

            /**
             * 判断强行降级Http开关是否打开
             * @return
             */
            @Override
            public boolean isForce2HttpFlag() {
                return JDNetworkDependencyFactory.getExternalDebugConfigImpl().isForceHttpDownGrade();
            }
        };
    }

    /**
     * 实现图片其他参数设置接口
     * @return
     */
    public static IImageController getImageControllerImpl(){
        return new IImageController() {
            /**
             * 调用图片模块所在页面
             * @return
             */
            @Override
            public String getThisPageInfo() {
                return PageInfoUtils.getThisPageInfo();
            }

            /**
             * 无图版开关
             * @return
             */
            @Override
            public boolean needNoImage() {
                return NoImageUtils.needNoImage();
            }
        };
    }

    /**
     * Sentry流量依赖
     * @return
     */
    public static IOtherDependency getOtherDependencyImpl() {
        return new IOtherDependency() {
            @Override
            public void sentryMarkRequestInfo(String url, int size, int type, int lasts, String ctp, int isSupportWebp) {
                RequestInfoCollector.getInstance().markRequestInfo(url, size,
                        type, lasts, ctp, isSupportWebp);
            }
        };
    }

    /**
     * 添加统计埋点
     * @return
     */
    public static INetStatReporter getNetStatReporterImpl() {
        return new INetStatReporter() {
            @Override
            public void saveStatisticData(HashMap<String, Integer> map) {
                StatSharePreferenceUtil.putIntMap(map);
            }
        };
    }

    public static IHttpDnsDependency getHttpDnsDenpendency() {
        return new IHttpDnsDependency() {

            @Override
            public IpModel getIpModelByHost(String host, boolean ignoreTTL) {
                com.jingdong.sdk.jdhttpdns.pojo.IpModel dnsModel
                        = ignoreTTL ? JDHttpDnsToolkit.getInstance().getIpFromMemoryCache(host)
                        : JDHttpDnsToolkit.getInstance().getIpModelByHost(host, true);
                return dnsModel == null ? null : new IpModel(dnsModel.host, dnsModel.master, dnsModel.v4, dnsModel.v6);
            }
        };
    }
}
````
